From e0847f5457edfdeb17dad259f1cd06b1d4cec93e Mon Sep 17 00:00:00 2001
From: Jhon Honce <jhonce@redhat.com>
Date: Thu, 2 Apr 2020 15:58:23 -0700
Subject: V2 podman system service

* Added support for system service
* Enabled linting on the varlinkapi source, needed to support V2
  service command
* Added support for PODMAN_SOCKET

Skip linting deprecated code

Rather than introduce bugs by correcting deprecated code, linting the
code is being skipped. Code that is being ported into V2 is being
checked.

Signed-off-by: Jhon Honce <jhonce@redhat.com>
---
 test/e2e/common_test.go | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'test/e2e')

diff --git a/test/e2e/common_test.go b/test/e2e/common_test.go
index 8c4fe9223..d93ee8d3a 100644
--- a/test/e2e/common_test.go
+++ b/test/e2e/common_test.go
@@ -221,8 +221,8 @@ func PodmanTestCreateUtil(tempDir string, remote bool) *PodmanTestIntegration {
 	ociRuntime := os.Getenv("OCI_RUNTIME")
 	if ociRuntime == "" {
 		var err error
-		ociRuntime, err = exec.LookPath("runc")
-		// If we cannot find the runc binary, setting to something static as we have no way
+		ociRuntime, err = exec.LookPath("crun")
+		// If we cannot find the crun binary, setting to something static as we have no way
 		// to return an error.  The tests will fail and point out that the runc binary could
 		// not be found nicely.
 		if err != nil {
-- 
cgit v1.2.3-54-g00ecf